    POSSIBILITIES:

    	[ ] YOU CAN TURN YOUR SCREEN READER OFF,
    		AND VOICE SYNTHESIS IS PLAYED UPON
    		FOCUS OF CERTAIN the_elementS.

    	[ ] THE SHIFT KEY & A ALPHANUMERIC KEY = PROBABLY NOT A OS COMBINATION.

    	decor:
    		EVERY:
    			POSSIBILITIES:
    				[ ] PRESS "i" GET INFORMATION ABOUT THE decor.
    				[ ] PRESS "a" GET ACADEMIC INFORMATION ABOUT THE decor STACK.

    			REGION STACK:

    		REGIONS:
    			WHILE NOT FOCUSED IN A TEXT INPUT

    			KINDS:
    				NAV, MAIN

    			NEXT:
    				R

    			PREV:
    				SHIFT & R

    		TABLES:

    		LISTS:
    			UL & OL:
    				NEXT:

    				PREV:

    		INPUTS:
    			[ESCAPE] TO FOCUS ON A TEMPORARY TABINDEX BEFORE THE TEXT INPUT.

    			TEXT:

    		TEXT:
    			HOW TO READ TEXT?

    				https://developer.mozilla.org/en-US/docs/Web/API/SpeechSynthesis

    				https://github.com/do-community/web-speech-demo/blob/master/public/main.js

    				https://developer.mozilla.org/en-US/docs/Web/API/Web_Speech_API

    				https://rapidapi.com/collection/best-text-to-speech-apis

    				https://cloud.google.com/text-to-speech

    	PERTINENT:
    		https://webaim.org/techniques/keyboard/accesskey